# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestSummary(object):
    """
    A work request summary
    """

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "INSTALL"
    OPERATION_TYPE_INSTALL = "INSTALL"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATE"
    OPERATION_TYPE_UPDATE = "UPDATE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "REMOVE"
    OPERATION_TYPE_REMOVE = "REMOVE"

    #: A constant which can be used with the operation_type property of a WorkRequestSummary.
    #: This constant has a value of "UPDATEALL"
    OPERATION_TYPE_UPDATEALL = "UPDATEALL"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "CANCELLING"
    STATUS_CANCELLING = "CANCELLING"

    #: A constant which can be used with the status property of a WorkRequestSummary.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    #: A constant which can be used with the os_family property of a WorkRequestSummary.
    #: This constant has a value of "LINUX"
    OS_FAMILY_LINUX = "LINUX"

    #: A constant which can be used with the os_family property of a WorkRequestSummary.
    #: This constant has a value of "WINDOWS"
    OS_FAMILY_WINDOWS = "WINDOWS"

    #: A constant which can be used with the os_family property of a WorkRequestSummary.
    #: This constant has a value of "ALL"
    OS_FAMILY_ALL = "ALL"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation_type:
            The value to assign to the operation_type property of this WorkRequestSummary.
            Allowed values for this property are: "INSTALL", "UPDATE", "REMOVE", "UPDATEALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_type: str

        :param status:
            The value to assign to the status property of this WorkRequestSummary.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELLING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param id:
            The value to assign to the id property of this WorkRequestSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this WorkRequestSummary.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this WorkRequestSummary.
        :type description: str

        :param message:
            The value to assign to the message property of this WorkRequestSummary.
        :type message: str

        :param percent_complete:
            The value to assign to the percent_complete property of this WorkRequestSummary.
        :type percent_complete: float

        :param time_accepted:
            The value to assign to the time_accepted property of this WorkRequestSummary.
        :type time_accepted: datetime

        :param os_family:
            The value to assign to the os_family property of this WorkRequestSummary.
            Allowed values for this property are: "LINUX", "WINDOWS", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type os_family: str

        """
        self.swagger_types = {
            'operation_type': 'str',
            'status': 'str',
            'id': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'message': 'str',
            'percent_complete': 'float',
            'time_accepted': 'datetime',
            'os_family': 'str'
        }

        self.attribute_map = {
            'operation_type': 'operationType',
            'status': 'status',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'message': 'message',
            'percent_complete': 'percentComplete',
            'time_accepted': 'timeAccepted',
            'os_family': 'osFamily'
        }

        self._operation_type = None
        self._status = None
        self._id = None
        self._compartment_id = None
        self._description = None
        self._message = None
        self._percent_complete = None
        self._time_accepted = None
        self._os_family = None

    @property
    def operation_type(self):
        """
        **[Required]** Gets the operation_type of this WorkRequestSummary.
        the type of operation this Work Request performs

        Allowed values for this property are: "INSTALL", "UPDATE", "REMOVE", "UPDATEALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_type of this WorkRequestSummary.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this WorkRequestSummary.
        the type of operation this Work Request performs


        :param operation_type: The operation_type of this WorkRequestSummary.
        :type: str
        """
        allowed_values = ["INSTALL", "UPDATE", "REMOVE", "UPDATEALL"]
        if not value_allowed_none_or_none_sentinel(operation_type, allowed_values):
            operation_type = 'UNKNOWN_ENUM_VALUE'
        self._operation_type = operation_type

    @property
    def status(self):
        """
        **[Required]** Gets the status of this WorkRequestSummary.
        status of current work request.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELLING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this WorkRequestSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WorkRequestSummary.
        status of current work request.


        :param status: The status of this WorkRequestSummary.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELLING", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def id(self):
        """
        **[Required]** Gets the id of this WorkRequestSummary.
        The id of the work request.


        :return: The id of this WorkRequestSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkRequestSummary.
        The id of the work request.


        :param id: The id of this WorkRequestSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this WorkRequestSummary.
        The ocid of the compartment that contains the work request. Work requests should be scoped to
        the same compartment as the resource the work request affects. If the work request affects multiple resources,
        and those resources are not in the same compartment, it is up to the service team to pick the primary
        resource whose compartment should be used


        :return: The compartment_id of this WorkRequestSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this WorkRequestSummary.
        The ocid of the compartment that contains the work request. Work requests should be scoped to
        the same compartment as the resource the work request affects. If the work request affects multiple resources,
        and those resources are not in the same compartment, it is up to the service team to pick the primary
        resource whose compartment should be used


        :param compartment_id: The compartment_id of this WorkRequestSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this WorkRequestSummary.
        Description of the type of work.


        :return: The description of this WorkRequestSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WorkRequestSummary.
        Description of the type of work.


        :param description: The description of this WorkRequestSummary.
        :type: str
        """
        self._description = description

    @property
    def message(self):
        """
        Gets the message of this WorkRequestSummary.
        A progress or error message, if there is any.


        :return: The message of this WorkRequestSummary.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this WorkRequestSummary.
        A progress or error message, if there is any.


        :param message: The message of this WorkRequestSummary.
        :type: str
        """
        self._message = message

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this WorkRequestSummary.
        Percentage of the request completed.


        :return: The percent_complete of this WorkRequestSummary.
        :rtype: float
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this WorkRequestSummary.
        Percentage of the request completed.


        :param percent_complete: The percent_complete of this WorkRequestSummary.
        :type: float
        """
        self._percent_complete = percent_complete

    @property
    def time_accepted(self):
        """
        **[Required]** Gets the time_accepted of this WorkRequestSummary.
        The date and time the request was created, as described in
        `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_accepted of this WorkRequestSummary.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this WorkRequestSummary.
        The date and time the request was created, as described in
        `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_accepted: The time_accepted of this WorkRequestSummary.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def os_family(self):
        """
        Gets the os_family of this WorkRequestSummary.
        The Operating System type of the managed instance.

        Allowed values for this property are: "LINUX", "WINDOWS", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The os_family of this WorkRequestSummary.
        :rtype: str
        """
        return self._os_family

    @os_family.setter
    def os_family(self, os_family):
        """
        Sets the os_family of this WorkRequestSummary.
        The Operating System type of the managed instance.


        :param os_family: The os_family of this WorkRequestSummary.
        :type: str
        """
        allowed_values = ["LINUX", "WINDOWS", "ALL"]
        if not value_allowed_none_or_none_sentinel(os_family, allowed_values):
            os_family = 'UNKNOWN_ENUM_VALUE'
        self._os_family = os_family

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Capacity(object):
    """
    Service instance capacity metadata (e.g.: OLPU count, number of users, ...etc...).
    """

    #: A constant which can be used with the capacity_type property of a Capacity.
    #: This constant has a value of "OLPU_COUNT"
    CAPACITY_TYPE_OLPU_COUNT = "OLPU_COUNT"

    #: A constant which can be used with the capacity_type property of a Capacity.
    #: This constant has a value of "USER_COUNT"
    CAPACITY_TYPE_USER_COUNT = "USER_COUNT"

    def __init__(self, **kwargs):
        """
        Initializes a new Capacity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param capacity_type:
            The value to assign to the capacity_type property of this Capacity.
            Allowed values for this property are: "OLPU_COUNT", "USER_COUNT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type capacity_type: str

        :param capacity_value:
            The value to assign to the capacity_value property of this Capacity.
        :type capacity_value: int

        """
        self.swagger_types = {
            'capacity_type': 'str',
            'capacity_value': 'int'
        }

        self.attribute_map = {
            'capacity_type': 'capacityType',
            'capacity_value': 'capacityValue'
        }

        self._capacity_type = None
        self._capacity_value = None

    @property
    def capacity_type(self):
        """
        **[Required]** Gets the capacity_type of this Capacity.
        The capacity model to use.

        Allowed values for this property are: "OLPU_COUNT", "USER_COUNT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The capacity_type of this Capacity.
        :rtype: str
        """
        return self._capacity_type

    @capacity_type.setter
    def capacity_type(self, capacity_type):
        """
        Sets the capacity_type of this Capacity.
        The capacity model to use.


        :param capacity_type: The capacity_type of this Capacity.
        :type: str
        """
        allowed_values = ["OLPU_COUNT", "USER_COUNT"]
        if not value_allowed_none_or_none_sentinel(capacity_type, allowed_values):
            capacity_type = 'UNKNOWN_ENUM_VALUE'
        self._capacity_type = capacity_type

    @property
    def capacity_value(self):
        """
        **[Required]** Gets the capacity_value of this Capacity.
        The capacity value selected (OLPU count, number of users, ...etc...). This parameter affects the
        number of CPUs, amount of memory or other resources allocated to the instance.


        :return: The capacity_value of this Capacity.
        :rtype: int
        """
        return self._capacity_value

    @capacity_value.setter
    def capacity_value(self, capacity_value):
        """
        Sets the capacity_value of this Capacity.
        The capacity value selected (OLPU count, number of users, ...etc...). This parameter affects the
        number of CPUs, amount of memory or other resources allocated to the instance.


        :param capacity_value: The capacity_value of this Capacity.
        :type: int
        """
        self._capacity_value = capacity_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_command_descriptor import AbstractCommandDescriptor
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterCompareCommandDescriptor(AbstractCommandDescriptor):
    """
    Command descriptor for querylanguage CLUSTERCOMPARE command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterCompareCommandDescriptor object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.ClusterCompareCommandDescriptor.name` attribute
        of this class is ``CLUSTER_COMPARE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ClusterCompareCommandDescriptor.
            Allowed values for this property are: "COMMAND", "SEARCH", "STATS", "TIME_STATS", "SORT", "FIELDS", "ADD_FIELDS", "LINK", "LINK_DETAILS", "CLUSTER", "CLUSTER_DETAILS", "CUSLTER_SPLIT", "EVAL", "EXTRACT", "EVENT_STATS", "BUCKET", "CLASSIFY", "TOP", "BOTTOM", "HEAD", "TAIL", "FIELD_SUMMARY", "REGEX", "RENAME", "TIME_COMPARE", "WHERE", "CLUSTER_COMPARE", "DELETE", "DELTA", "DISTINCT", "SEARCH_LOOKUP", "LOOKUP", "DEMO_MODE", "MACRO", "MULTI_SEARCH", "HIGHLIGHT", "HIGHLIGHT_ROWS"
        :type name: str

        :param display_query_string:
            The value to assign to the display_query_string property of this ClusterCompareCommandDescriptor.
        :type display_query_string: str

        :param internal_query_string:
            The value to assign to the internal_query_string property of this ClusterCompareCommandDescriptor.
        :type internal_query_string: str

        :param category:
            The value to assign to the category property of this ClusterCompareCommandDescriptor.
        :type category: str

        :param referenced_fields:
            The value to assign to the referenced_fields property of this ClusterCompareCommandDescriptor.
        :type referenced_fields: list[AbstractField]

        :param declared_fields:
            The value to assign to the declared_fields property of this ClusterCompareCommandDescriptor.
        :type declared_fields: list[AbstractField]

        :param time_shift:
            The value to assign to the time_shift property of this ClusterCompareCommandDescriptor.
        :type time_shift: str

        :param time_start:
            The value to assign to the time_start property of this ClusterCompareCommandDescriptor.
        :type time_start: int

        :param time_end:
            The value to assign to the time_end property of this ClusterCompareCommandDescriptor.
        :type time_end: int

        :param should_include_trends:
            The value to assign to the should_include_trends property of this ClusterCompareCommandDescriptor.
        :type should_include_trends: bool

        :param span:
            The value to assign to the span property of this ClusterCompareCommandDescriptor.
        :type span: str

        :param baseline_query:
            The value to assign to the baseline_query property of this ClusterCompareCommandDescriptor.
        :type baseline_query: str

        """
        self.swagger_types = {
            'name': 'str',
            'display_query_string': 'str',
            'internal_query_string': 'str',
            'category': 'str',
            'referenced_fields': 'list[AbstractField]',
            'declared_fields': 'list[AbstractField]',
            'time_shift': 'str',
            'time_start': 'int',
            'time_end': 'int',
            'should_include_trends': 'bool',
            'span': 'str',
            'baseline_query': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'display_query_string': 'displayQueryString',
            'internal_query_string': 'internalQueryString',
            'category': 'category',
            'referenced_fields': 'referencedFields',
            'declared_fields': 'declaredFields',
            'time_shift': 'timeShift',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'should_include_trends': 'shouldIncludeTrends',
            'span': 'span',
            'baseline_query': 'baselineQuery'
        }

        self._name = None
        self._display_query_string = None
        self._internal_query_string = None
        self._category = None
        self._referenced_fields = None
        self._declared_fields = None
        self._time_shift = None
        self._time_start = None
        self._time_end = None
        self._should_include_trends = None
        self._span = None
        self._baseline_query = None
        self._name = 'CLUSTER_COMPARE'

    @property
    def time_shift(self):
        """
        Gets the time_shift of this ClusterCompareCommandDescriptor.
        To shift time range of main query backwards using a relative time expression e.g -24hrs. E.g compare against the previous 24 hrs.


        :return: The time_shift of this ClusterCompareCommandDescriptor.
        :rtype: str
        """
        return self._time_shift

    @time_shift.setter
    def time_shift(self, time_shift):
        """
        Sets the time_shift of this ClusterCompareCommandDescriptor.
        To shift time range of main query backwards using a relative time expression e.g -24hrs. E.g compare against the previous 24 hrs.


        :param time_shift: The time_shift of this ClusterCompareCommandDescriptor.
        :type: str
        """
        self._time_shift = time_shift

    @property
    def time_start(self):
        """
        Gets the time_start of this ClusterCompareCommandDescriptor.
        Start time to apply to base line query if specified.


        :return: The time_start of this ClusterCompareCommandDescriptor.
        :rtype: int
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this ClusterCompareCommandDescriptor.
        Start time to apply to base line query if specified.


        :param time_start: The time_start of this ClusterCompareCommandDescriptor.
        :type: int
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this ClusterCompareCommandDescriptor.
        End time to apply to base line query if specified.


        :return: The time_end of this ClusterCompareCommandDescriptor.
        :rtype: int
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this ClusterCompareCommandDescriptor.
        End time to apply to base line query if specified.


        :param time_end: The time_end of this ClusterCompareCommandDescriptor.
        :type: int
        """
        self._time_end = time_end

    @property
    def should_include_trends(self):
        """
        Gets the should_include_trends of this ClusterCompareCommandDescriptor.
        Option to calculate trends of each cluster if specified.


        :return: The should_include_trends of this ClusterCompareCommandDescriptor.
        :rtype: bool
        """
        return self._should_include_trends

    @should_include_trends.setter
    def should_include_trends(self, should_include_trends):
        """
        Sets the should_include_trends of this ClusterCompareCommandDescriptor.
        Option to calculate trends of each cluster if specified.


        :param should_include_trends: The should_include_trends of this ClusterCompareCommandDescriptor.
        :type: bool
        """
        self._should_include_trends = should_include_trends

    @property
    def span(self):
        """
        Gets the span of this ClusterCompareCommandDescriptor.
        Option to control the size of buckets in the histogram e.g 8hrs  - each bar other than first and last should represent 8hr time span. Will be adjusted to a larger span if time range is very large.


        :return: The span of this ClusterCompareCommandDescriptor.
        :rtype: str
        """
        return self._span

    @span.setter
    def span(self, span):
        """
        Sets the span of this ClusterCompareCommandDescriptor.
        Option to control the size of buckets in the histogram e.g 8hrs  - each bar other than first and last should represent 8hr time span. Will be adjusted to a larger span if time range is very large.


        :param span: The span of this ClusterCompareCommandDescriptor.
        :type: str
        """
        self._span = span

    @property
    def baseline_query(self):
        """
        Gets the baseline_query of this ClusterCompareCommandDescriptor.
        Query to use to compute base line to compare top level query results against to identify differences if specified.


        :return: The baseline_query of this ClusterCompareCommandDescriptor.
        :rtype: str
        """
        return self._baseline_query

    @baseline_query.setter
    def baseline_query(self, baseline_query):
        """
        Sets the baseline_query of this ClusterCompareCommandDescriptor.
        Query to use to compute base line to compare top level query results against to identify differences if specified.


        :param baseline_query: The baseline_query of this ClusterCompareCommandDescriptor.
        :type: str
        """
        self._baseline_query = baseline_query

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Quota(object):
    """
    Quotas are applied on top of the service limits and inherited through the nested compartment hierarchy.
    They allow compartment admins to limit resource consumption and set boundaries around acceptable resource use.
    The word \"quota\" is used by people in different ways:
    * An individual statement written in the declarative language
    * A collection of statements in a single, named \"quota\" object (which has an Oracle Cloud ID (OCID) assigned to it)
    * The overall body of quotas your organization uses to control access to resources
    """

    #: A constant which can be used with the lifecycle_state property of a Quota.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new Quota object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Quota.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Quota.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this Quota.
        :type name: str

        :param statements:
            The value to assign to the statements property of this Quota.
        :type statements: list[str]

        :param description:
            The value to assign to the description property of this Quota.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this Quota.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Quota.
            Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Quota.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Quota.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'statements': 'list[str]',
            'description': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'statements': 'statements',
            'description': 'description',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._name = None
        self._statements = None
        self._description = None
        self._time_created = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Quota.
        The OCID of the quota.


        :return: The id of this Quota.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Quota.
        The OCID of the quota.


        :param id: The id of this Quota.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Quota.
        The OCID of the compartment containing the resource this quota applies to.


        :return: The compartment_id of this Quota.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Quota.
        The OCID of the compartment containing the resource this quota applies to.


        :param compartment_id: The compartment_id of this Quota.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Quota.
        The name you assign to the quota during creation. The name must be unique across all quotas
        in the tenancy and cannot be changed.


        :return: The name of this Quota.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Quota.
        The name you assign to the quota during creation. The name must be unique across all quotas
        in the tenancy and cannot be changed.


        :param name: The name of this Quota.
        :type: str
        """
        self._name = name

    @property
    def statements(self):
        """
        **[Required]** Gets the statements of this Quota.
        An array of one or more quota statements written in the declarative quota statement language.


        :return: The statements of this Quota.
        :rtype: list[str]
        """
        return self._statements

    @statements.setter
    def statements(self, statements):
        """
        Sets the statements of this Quota.
        An array of one or more quota statements written in the declarative quota statement language.


        :param statements: The statements of this Quota.
        :type: list[str]
        """
        self._statements = statements

    @property
    def description(self):
        """
        **[Required]** Gets the description of this Quota.
        The description you assign to the quota.


        :return: The description of this Quota.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Quota.
        The description you assign to the quota.


        :param description: The description of this Quota.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Quota.
        Date and time the quota was created, in the format defined by RFC3339.
        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this Quota.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Quota.
        Date and time the quota was created, in the format defined by RFC3339.
        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this Quota.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Quota.
        The quota's current state. After creating a quota, make sure its `lifecycleState` is set to
        ACTIVE before using it.

        Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Quota.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Quota.
        The quota's current state. After creating a quota, make sure its `lifecycleState` is set to
        ACTIVE before using it.


        :param lifecycle_state: The lifecycle_state of this Quota.
        :type: str
        """
        allowed_values = ["ACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Quota.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Quota.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Quota.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Quota.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Quota.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Quota.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Quota.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Quota.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_configuration_instance_details import InstanceConfigurationInstanceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceDetails(InstanceConfigurationInstanceDetails):
    """
    Compute Instance Configuration instance details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.ComputeInstanceDetails.instance_type` attribute
        of this class is ``compute`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_type:
            The value to assign to the instance_type property of this ComputeInstanceDetails.
        :type instance_type: str

        :param block_volumes:
            The value to assign to the block_volumes property of this ComputeInstanceDetails.
        :type block_volumes: list[InstanceConfigurationBlockVolumeDetails]

        :param launch_details:
            The value to assign to the launch_details property of this ComputeInstanceDetails.
        :type launch_details: InstanceConfigurationLaunchInstanceDetails

        :param secondary_vnics:
            The value to assign to the secondary_vnics property of this ComputeInstanceDetails.
        :type secondary_vnics: list[InstanceConfigurationAttachVnicDetails]

        """
        self.swagger_types = {
            'instance_type': 'str',
            'block_volumes': 'list[InstanceConfigurationBlockVolumeDetails]',
            'launch_details': 'InstanceConfigurationLaunchInstanceDetails',
            'secondary_vnics': 'list[InstanceConfigurationAttachVnicDetails]'
        }

        self.attribute_map = {
            'instance_type': 'instanceType',
            'block_volumes': 'blockVolumes',
            'launch_details': 'launchDetails',
            'secondary_vnics': 'secondaryVnics'
        }

        self._instance_type = None
        self._block_volumes = None
        self._launch_details = None
        self._secondary_vnics = None
        self._instance_type = 'compute'

    @property
    def block_volumes(self):
        """
        Gets the block_volumes of this ComputeInstanceDetails.

        :return: The block_volumes of this ComputeInstanceDetails.
        :rtype: list[InstanceConfigurationBlockVolumeDetails]
        """
        return self._block_volumes

    @block_volumes.setter
    def block_volumes(self, block_volumes):
        """
        Sets the block_volumes of this ComputeInstanceDetails.

        :param block_volumes: The block_volumes of this ComputeInstanceDetails.
        :type: list[InstanceConfigurationBlockVolumeDetails]
        """
        self._block_volumes = block_volumes

    @property
    def launch_details(self):
        """
        Gets the launch_details of this ComputeInstanceDetails.

        :return: The launch_details of this ComputeInstanceDetails.
        :rtype: InstanceConfigurationLaunchInstanceDetails
        """
        return self._launch_details

    @launch_details.setter
    def launch_details(self, launch_details):
        """
        Sets the launch_details of this ComputeInstanceDetails.

        :param launch_details: The launch_details of this ComputeInstanceDetails.
        :type: InstanceConfigurationLaunchInstanceDetails
        """
        self._launch_details = launch_details

    @property
    def secondary_vnics(self):
        """
        Gets the secondary_vnics of this ComputeInstanceDetails.

        :return: The secondary_vnics of this ComputeInstanceDetails.
        :rtype: list[InstanceConfigurationAttachVnicDetails]
        """
        return self._secondary_vnics

    @secondary_vnics.setter
    def secondary_vnics(self, secondary_vnics):
        """
        Sets the secondary_vnics of this ComputeInstanceDetails.

        :param secondary_vnics: The secondary_vnics of this ComputeInstanceDetails.
        :type: list[InstanceConfigurationAttachVnicDetails]
        """
        self._secondary_vnics = secondary_vnics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VmClusterSummary(object):
    """
    Details of the VM cluster.
    """

    #: A constant which can be used with the lifecycle_state property of a VmClusterSummary.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a VmClusterSummary.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a VmClusterSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a VmClusterSummary.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a VmClusterSummary.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a VmClusterSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the license_model property of a VmClusterSummary.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a VmClusterSummary.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new VmClusterSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VmClusterSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this VmClusterSummary.
        :type compartment_id: str

        :param last_patch_history_entry_id:
            The value to assign to the last_patch_history_entry_id property of this VmClusterSummary.
        :type last_patch_history_entry_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VmClusterSummary.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param display_name:
            The value to assign to the display_name property of this VmClusterSummary.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this VmClusterSummary.
        :type time_created: datetime

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this VmClusterSummary.
        :type lifecycle_details: str

        :param time_zone:
            The value to assign to the time_zone property of this VmClusterSummary.
        :type time_zone: str

        :param is_local_backup_enabled:
            The value to assign to the is_local_backup_enabled property of this VmClusterSummary.
        :type is_local_backup_enabled: bool

        :param exadata_infrastructure_id:
            The value to assign to the exadata_infrastructure_id property of this VmClusterSummary.
        :type exadata_infrastructure_id: str

        :param is_sparse_diskgroup_enabled:
            The value to assign to the is_sparse_diskgroup_enabled property of this VmClusterSummary.
        :type is_sparse_diskgroup_enabled: bool

        :param vm_cluster_network_id:
            The value to assign to the vm_cluster_network_id property of this VmClusterSummary.
        :type vm_cluster_network_id: str

        :param cpus_enabled:
            The value to assign to the cpus_enabled property of this VmClusterSummary.
        :type cpus_enabled: int

        :param memory_size_in_gbs:
            The value to assign to the memory_size_in_gbs property of this VmClusterSummary.
        :type memory_size_in_gbs: int

        :param db_node_storage_size_in_gbs:
            The value to assign to the db_node_storage_size_in_gbs property of this VmClusterSummary.
        :type db_node_storage_size_in_gbs: int

        :param data_storage_size_in_tbs:
            The value to assign to the data_storage_size_in_tbs property of this VmClusterSummary.
        :type data_storage_size_in_tbs: float

        :param shape:
            The value to assign to the shape property of this VmClusterSummary.
        :type shape: str

        :param gi_version:
            The value to assign to the gi_version property of this VmClusterSummary.
        :type gi_version: str

        :param ssh_public_keys:
            The value to assign to the ssh_public_keys property of this VmClusterSummary.
        :type ssh_public_keys: list[str]

        :param license_model:
            The value to assign to the license_model property of this VmClusterSummary.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_model: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this VmClusterSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this VmClusterSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'last_patch_history_entry_id': 'str',
            'lifecycle_state': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'lifecycle_details': 'str',
            'time_zone': 'str',
            'is_local_backup_enabled': 'bool',
            'exadata_infrastructure_id': 'str',
            'is_sparse_diskgroup_enabled': 'bool',
            'vm_cluster_network_id': 'str',
            'cpus_enabled': 'int',
            'memory_size_in_gbs': 'int',
            'db_node_storage_size_in_gbs': 'int',
            'data_storage_size_in_tbs': 'float',
            'shape': 'str',
            'gi_version': 'str',
            'ssh_public_keys': 'list[str]',
            'license_model': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'last_patch_history_entry_id': 'lastPatchHistoryEntryId',
            'lifecycle_state': 'lifecycleState',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'lifecycle_details': 'lifecycleDetails',
            'time_zone': 'timeZone',
            'is_local_backup_enabled': 'isLocalBackupEnabled',
            'exadata_infrastructure_id': 'exadataInfrastructureId',
            'is_sparse_diskgroup_enabled': 'isSparseDiskgroupEnabled',
            'vm_cluster_network_id': 'vmClusterNetworkId',
            'cpus_enabled': 'cpusEnabled',
            'memory_size_in_gbs': 'memorySizeInGBs',
            'db_node_storage_size_in_gbs': 'dbNodeStorageSizeInGBs',
            'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
            'shape': 'shape',
            'gi_version': 'giVersion',
            'ssh_public_keys': 'sshPublicKeys',
            'license_model': 'licenseModel',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._last_patch_history_entry_id = None
        self._lifecycle_state = None
        self._display_name = None
        self._time_created = None
        self._lifecycle_details = None
        self._time_zone = None
        self._is_local_backup_enabled = None
        self._exadata_infrastructure_id = None
        self._is_sparse_diskgroup_enabled = None
        self._vm_cluster_network_id = None
        self._cpus_enabled = None
        self._memory_size_in_gbs = None
        self._db_node_storage_size_in_gbs = None
        self._data_storage_size_in_tbs = None
        self._shape = None
        self._gi_version = None
        self._ssh_public_keys = None
        self._license_model = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        Gets the id of this VmClusterSummary.
        The `OCID`__ of the VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this VmClusterSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VmClusterSummary.
        The `OCID`__ of the VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this VmClusterSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this VmClusterSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this VmClusterSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VmClusterSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this VmClusterSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def last_patch_history_entry_id(self):
        """
        Gets the last_patch_history_entry_id of this VmClusterSummary.
        The `OCID`__ of the last patch history. This value is updated as soon as a patch operation starts.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_patch_history_entry_id of this VmClusterSummary.
        :rtype: str
        """
        return self._last_patch_history_entry_id

    @last_patch_history_entry_id.setter
    def last_patch_history_entry_id(self, last_patch_history_entry_id):
        """
        Sets the last_patch_history_entry_id of this VmClusterSummary.
        The `OCID`__ of the last patch history. This value is updated as soon as a patch operation starts.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_patch_history_entry_id: The last_patch_history_entry_id of this VmClusterSummary.
        :type: str
        """
        self._last_patch_history_entry_id = last_patch_history_entry_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this VmClusterSummary.
        The current state of the VM cluster.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VmClusterSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VmClusterSummary.
        The current state of the VM cluster.


        :param lifecycle_state: The lifecycle_state of this VmClusterSummary.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def display_name(self):
        """
        Gets the display_name of this VmClusterSummary.
        The user-friendly name for the VM cluster. The name does not need to be unique.


        :return: The display_name of this VmClusterSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this VmClusterSummary.
        The user-friendly name for the VM cluster. The name does not need to be unique.


        :param display_name: The display_name of this VmClusterSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        Gets the time_created of this VmClusterSummary.
        The date and time that the VM cluster was created.


        :return: The time_created of this VmClusterSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this VmClusterSummary.
        The date and time that the VM cluster was created.


        :param time_created: The time_created of this VmClusterSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this VmClusterSummary.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this VmClusterSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this VmClusterSummary.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this VmClusterSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_zone(self):
        """
        Gets the time_zone of this VmClusterSummary.
        The time zone of the Exadata infrastructure. For details, see `Exadata Infrastructure Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The time_zone of this VmClusterSummary.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this VmClusterSummary.
        The time zone of the Exadata infrastructure. For details, see `Exadata Infrastructure Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param time_zone: The time_zone of this VmClusterSummary.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def is_local_backup_enabled(self):
        """
        Gets the is_local_backup_enabled of this VmClusterSummary.
        If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.


        :return: The is_local_backup_enabled of this VmClusterSummary.
        :rtype: bool
        """
        return self._is_local_backup_enabled

    @is_local_backup_enabled.setter
    def is_local_backup_enabled(self, is_local_backup_enabled):
        """
        Sets the is_local_backup_enabled of this VmClusterSummary.
        If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.


        :param is_local_backup_enabled: The is_local_backup_enabled of this VmClusterSummary.
        :type: bool
        """
        self._is_local_backup_enabled = is_local_backup_enabled

    @property
    def exadata_infrastructure_id(self):
        """
        Gets the exadata_infrastructure_id of this VmClusterSummary.
        The `OCID`__ of the Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The exadata_infrastructure_id of this VmClusterSummary.
        :rtype: str
        """
        return self._exadata_infrastructure_id

    @exadata_infrastructure_id.setter
    def exadata_infrastructure_id(self, exadata_infrastructure_id):
        """
        Sets the exadata_infrastructure_id of this VmClusterSummary.
        The `OCID`__ of the Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param exadata_infrastructure_id: The exadata_infrastructure_id of this VmClusterSummary.
        :type: str
        """
        self._exadata_infrastructure_id = exadata_infrastructure_id

    @property
    def is_sparse_diskgroup_enabled(self):
        """
        Gets the is_sparse_diskgroup_enabled of this VmClusterSummary.
        If true, sparse disk group is configured for the VM cluster. If false, sparse disk group is not created.


        :return: The is_sparse_diskgroup_enabled of this VmClusterSummary.
        :rtype: bool
        """
        return self._is_sparse_diskgroup_enabled

    @is_sparse_diskgroup_enabled.setter
    def is_sparse_diskgroup_enabled(self, is_sparse_diskgroup_enabled):
        """
        Sets the is_sparse_diskgroup_enabled of this VmClusterSummary.
        If true, sparse disk group is configured for the VM cluster. If false, sparse disk group is not created.


        :param is_sparse_diskgroup_enabled: The is_sparse_diskgroup_enabled of this VmClusterSummary.
        :type: bool
        """
        self._is_sparse_diskgroup_enabled = is_sparse_diskgroup_enabled

    @property
    def vm_cluster_network_id(self):
        """
        Gets the vm_cluster_network_id of this VmClusterSummary.
        The `OCID`__ of the VM cluster network.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vm_cluster_network_id of this VmClusterSummary.
        :rtype: str
        """
        return self._vm_cluster_network_id

    @vm_cluster_network_id.setter
    def vm_cluster_network_id(self, vm_cluster_network_id):
        """
        Sets the vm_cluster_network_id of this VmClusterSummary.
        The `OCID`__ of the VM cluster network.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vm_cluster_network_id: The vm_cluster_network_id of this VmClusterSummary.
        :type: str
        """
        self._vm_cluster_network_id = vm_cluster_network_id

    @property
    def cpus_enabled(self):
        """
        Gets the cpus_enabled of this VmClusterSummary.
        The number of enabled CPU cores.


        :return: The cpus_enabled of this VmClusterSummary.
        :rtype: int
        """
        return self._cpus_enabled

    @cpus_enabled.setter
    def cpus_enabled(self, cpus_enabled):
        """
        Sets the cpus_enabled of this VmClusterSummary.
        The number of enabled CPU cores.


        :param cpus_enabled: The cpus_enabled of this VmClusterSummary.
        :type: int
        """
        self._cpus_enabled = cpus_enabled

    @property
    def memory_size_in_gbs(self):
        """
        Gets the memory_size_in_gbs of this VmClusterSummary.
        The memory allocated in GBs.


        :return: The memory_size_in_gbs of this VmClusterSummary.
        :rtype: int
        """
        return self._memory_size_in_gbs

    @memory_size_in_gbs.setter
    def memory_size_in_gbs(self, memory_size_in_gbs):
        """
        Sets the memory_size_in_gbs of this VmClusterSummary.
        The memory allocated in GBs.


        :param memory_size_in_gbs: The memory_size_in_gbs of this VmClusterSummary.
        :type: int
        """
        self._memory_size_in_gbs = memory_size_in_gbs

    @property
    def db_node_storage_size_in_gbs(self):
        """
        Gets the db_node_storage_size_in_gbs of this VmClusterSummary.
        The local node storage allocated in GBs.


        :return: The db_node_storage_size_in_gbs of this VmClusterSummary.
        :rtype: int
        """
        return self._db_node_storage_size_in_gbs

    @db_node_storage_size_in_gbs.setter
    def db_node_storage_size_in_gbs(self, db_node_storage_size_in_gbs):
        """
        Sets the db_node_storage_size_in_gbs of this VmClusterSummary.
        The local node storage allocated in GBs.


        :param db_node_storage_size_in_gbs: The db_node_storage_size_in_gbs of this VmClusterSummary.
        :type: int
        """
        self._db_node_storage_size_in_gbs = db_node_storage_size_in_gbs

    @property
    def data_storage_size_in_tbs(self):
        """
        Gets the data_storage_size_in_tbs of this VmClusterSummary.
        Size, in terabytes, of the DATA disk group.


        :return: The data_storage_size_in_tbs of this VmClusterSummary.
        :rtype: float
        """
        return self._data_storage_size_in_tbs

    @data_storage_size_in_tbs.setter
    def data_storage_size_in_tbs(self, data_storage_size_in_tbs):
        """
        Sets the data_storage_size_in_tbs of this VmClusterSummary.
        Size, in terabytes, of the DATA disk group.


        :param data_storage_size_in_tbs: The data_storage_size_in_tbs of this VmClusterSummary.
        :type: float
        """
        self._data_storage_size_in_tbs = data_storage_size_in_tbs

    @property
    def shape(self):
        """
        Gets the shape of this VmClusterSummary.
        The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.


        :return: The shape of this VmClusterSummary.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this VmClusterSummary.
        The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.


        :param shape: The shape of this VmClusterSummary.
        :type: str
        """
        self._shape = shape

    @property
    def gi_version(self):
        """
        Gets the gi_version of this VmClusterSummary.
        The Oracle Grid Infrastructure software version for the VM cluster.


        :return: The gi_version of this VmClusterSummary.
        :rtype: str
        """
        return self._gi_version

    @gi_version.setter
    def gi_version(self, gi_version):
        """
        Sets the gi_version of this VmClusterSummary.
        The Oracle Grid Infrastructure software version for the VM cluster.


        :param gi_version: The gi_version of this VmClusterSummary.
        :type: str
        """
        self._gi_version = gi_version

    @property
    def ssh_public_keys(self):
        """
        Gets the ssh_public_keys of this VmClusterSummary.
        The public key portion of one or more key pairs used for SSH access to the VM cluster.


        :return: The ssh_public_keys of this VmClusterSummary.
        :rtype: list[str]
        """
        return self._ssh_public_keys

    @ssh_public_keys.setter
    def ssh_public_keys(self, ssh_public_keys):
        """
        Sets the ssh_public_keys of this VmClusterSummary.
        The public key portion of one or more key pairs used for SSH access to the VM cluster.


        :param ssh_public_keys: The ssh_public_keys of this VmClusterSummary.
        :type: list[str]
        """
        self._ssh_public_keys = ssh_public_keys

    @property
    def license_model(self):
        """
        Gets the license_model of this VmClusterSummary.
        The Oracle license model that applies to the VM cluster. The default is LICENSE_INCLUDED.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_model of this VmClusterSummary.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this VmClusterSummary.
        The Oracle license model that applies to the VM cluster. The default is LICENSE_INCLUDED.


        :param license_model: The license_model of this VmClusterSummary.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            license_model = 'UNKNOWN_ENUM_VALUE'
        self._license_model = license_model

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this VmClusterSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this VmClusterSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this VmClusterSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this VmClusterSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this VmClusterSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this VmClusterSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this VmClusterSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this VmClusterSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Screenshot(object):
    """
    The model for a listing's screenshot.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Screenshot object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Screenshot.
        :type name: str

        :param description:
            The value to assign to the description property of this Screenshot.
        :type description: str

        :param content_url:
            The value to assign to the content_url property of this Screenshot.
        :type content_url: str

        :param mime_type:
            The value to assign to the mime_type property of this Screenshot.
        :type mime_type: str

        :param file_extension:
            The value to assign to the file_extension property of this Screenshot.
        :type file_extension: str

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'content_url': 'str',
            'mime_type': 'str',
            'file_extension': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'content_url': 'contentUrl',
            'mime_type': 'mimeType',
            'file_extension': 'fileExtension'
        }

        self._name = None
        self._description = None
        self._content_url = None
        self._mime_type = None
        self._file_extension = None

    @property
    def name(self):
        """
        Gets the name of this Screenshot.
        The name of the screenshot.


        :return: The name of this Screenshot.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Screenshot.
        The name of the screenshot.


        :param name: The name of this Screenshot.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Screenshot.
        A description of the screenshot.


        :return: The description of this Screenshot.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Screenshot.
        A description of the screenshot.


        :param description: The description of this Screenshot.
        :type: str
        """
        self._description = description

    @property
    def content_url(self):
        """
        Gets the content_url of this Screenshot.
        The content URL of the screenshot.


        :return: The content_url of this Screenshot.
        :rtype: str
        """
        return self._content_url

    @content_url.setter
    def content_url(self, content_url):
        """
        Sets the content_url of this Screenshot.
        The content URL of the screenshot.


        :param content_url: The content_url of this Screenshot.
        :type: str
        """
        self._content_url = content_url

    @property
    def mime_type(self):
        """
        Gets the mime_type of this Screenshot.
        The MIME type of the screenshot.


        :return: The mime_type of this Screenshot.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """
        Sets the mime_type of this Screenshot.
        The MIME type of the screenshot.


        :param mime_type: The mime_type of this Screenshot.
        :type: str
        """
        self._mime_type = mime_type

    @property
    def file_extension(self):
        """
        Gets the file_extension of this Screenshot.
        The file extension of the screenshot.


        :return: The file_extension of this Screenshot.
        :rtype: str
        """
        return self._file_extension

    @file_extension.setter
    def file_extension(self, file_extension):
        """
        Sets the file_extension of this Screenshot.
        The file extension of the screenshot.


        :param file_extension: The file_extension of this Screenshot.
        :type: str
        """
        self._file_extension = file_extension

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecurityScoreAggregation(object):
    """
    Provides the dimensions and their corresponding count value.
    """

    #: A constant which can be used with the security_rating property of a SecurityScoreAggregation.
    #: This constant has a value of "EXCELLENT"
    SECURITY_RATING_EXCELLENT = "EXCELLENT"

    #: A constant which can be used with the security_rating property of a SecurityScoreAggregation.
    #: This constant has a value of "GOOD"
    SECURITY_RATING_GOOD = "GOOD"

    #: A constant which can be used with the security_rating property of a SecurityScoreAggregation.
    #: This constant has a value of "FAIR"
    SECURITY_RATING_FAIR = "FAIR"

    #: A constant which can be used with the security_rating property of a SecurityScoreAggregation.
    #: This constant has a value of "POOR"
    SECURITY_RATING_POOR = "POOR"

    def __init__(self, **kwargs):
        """
        Initializes a new SecurityScoreAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dimensions_map:
            The value to assign to the dimensions_map property of this SecurityScoreAggregation.
        :type dimensions_map: dict(str, str)

        :param security_rating:
            The value to assign to the security_rating property of this SecurityScoreAggregation.
            Allowed values for this property are: "EXCELLENT", "GOOD", "FAIR", "POOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type security_rating: str

        :param security_score:
            The value to assign to the security_score property of this SecurityScoreAggregation.
        :type security_score: int

        """
        self.swagger_types = {
            'dimensions_map': 'dict(str, str)',
            'security_rating': 'str',
            'security_score': 'int'
        }

        self.attribute_map = {
            'dimensions_map': 'dimensionsMap',
            'security_rating': 'securityRating',
            'security_score': 'securityScore'
        }

        self._dimensions_map = None
        self._security_rating = None
        self._security_score = None

    @property
    def dimensions_map(self):
        """
        **[Required]** Gets the dimensions_map of this SecurityScoreAggregation.
        The key-value pairs of dimensions and their names.


        :return: The dimensions_map of this SecurityScoreAggregation.
        :rtype: dict(str, str)
        """
        return self._dimensions_map

    @dimensions_map.setter
    def dimensions_map(self, dimensions_map):
        """
        Sets the dimensions_map of this SecurityScoreAggregation.
        The key-value pairs of dimensions and their names.


        :param dimensions_map: The dimensions_map of this SecurityScoreAggregation.
        :type: dict(str, str)
        """
        self._dimensions_map = dimensions_map

    @property
    def security_rating(self):
        """
        **[Required]** Gets the security_rating of this SecurityScoreAggregation.
        The security rating with given dimension/s

        Allowed values for this property are: "EXCELLENT", "GOOD", "FAIR", "POOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The security_rating of this SecurityScoreAggregation.
        :rtype: str
        """
        return self._security_rating

    @security_rating.setter
    def security_rating(self, security_rating):
        """
        Sets the security_rating of this SecurityScoreAggregation.
        The security rating with given dimension/s


        :param security_rating: The security_rating of this SecurityScoreAggregation.
        :type: str
        """
        allowed_values = ["EXCELLENT", "GOOD", "FAIR", "POOR"]
        if not value_allowed_none_or_none_sentinel(security_rating, allowed_values):
            security_rating = 'UNKNOWN_ENUM_VALUE'
        self._security_rating = security_rating

    @property
    def security_score(self):
        """
        **[Required]** Gets the security_score of this SecurityScoreAggregation.
        The security score with given dimension/s


        :return: The security_score of this SecurityScoreAggregation.
        :rtype: int
        """
        return self._security_score

    @security_score.setter
    def security_score(self, security_score):
        """
        Sets the security_score of this SecurityScoreAggregation.
        The security score with given dimension/s


        :param security_score: The security_score of this SecurityScoreAggregation.
        :type: int
        """
        self._security_score = security_score

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResponderRuleExecutionDetails(object):
    """
    Details of ResponderRuleExecution. A Responder Rule Execution is the entity that captures the execution of a Responder Rule for a given Problem.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResponderRuleExecutionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param condition:
            The value to assign to the condition property of this ResponderRuleExecutionDetails.
        :type condition: Condition

        :param configurations:
            The value to assign to the configurations property of this ResponderRuleExecutionDetails.
        :type configurations: list[ResponderConfiguration]

        """
        self.swagger_types = {
            'condition': 'Condition',
            'configurations': 'list[ResponderConfiguration]'
        }

        self.attribute_map = {
            'condition': 'condition',
            'configurations': 'configurations'
        }

        self._condition = None
        self._configurations = None

    @property
    def condition(self):
        """
        Gets the condition of this ResponderRuleExecutionDetails.

        :return: The condition of this ResponderRuleExecutionDetails.
        :rtype: Condition
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this ResponderRuleExecutionDetails.

        :param condition: The condition of this ResponderRuleExecutionDetails.
        :type: Condition
        """
        self._condition = condition

    @property
    def configurations(self):
        """
        Gets the configurations of this ResponderRuleExecutionDetails.
        ResponderRule configurations


        :return: The configurations of this ResponderRuleExecutionDetails.
        :rtype: list[ResponderConfiguration]
        """
        return self._configurations

    @configurations.setter
    def configurations(self, configurations):
        """
        Sets the configurations of this ResponderRuleExecutionDetails.
        ResponderRule configurations


        :param configurations: The configurations of this ResponderRuleExecutionDetails.
        :type: list[ResponderConfiguration]
        """
        self._configurations = configurations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UploadFileSummary(object):
    """
    Details of Upload File.
    """

    #: A constant which can be used with the status property of a UploadFileSummary.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a UploadFileSummary.
    #: This constant has a value of "SUCCESSFUL"
    STATUS_SUCCESSFUL = "SUCCESSFUL"

    #: A constant which can be used with the status property of a UploadFileSummary.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new UploadFileSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param reference:
            The value to assign to the reference property of this UploadFileSummary.
        :type reference: str

        :param name:
            The value to assign to the name property of this UploadFileSummary.
        :type name: str

        :param status:
            The value to assign to the status property of this UploadFileSummary.
            Allowed values for this property are: "IN_PROGRESS", "SUCCESSFUL", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param total_chunks:
            The value to assign to the total_chunks property of this UploadFileSummary.
        :type total_chunks: float

        :param chunks_consumed:
            The value to assign to the chunks_consumed property of this UploadFileSummary.
        :type chunks_consumed: float

        :param chunks_success:
            The value to assign to the chunks_success property of this UploadFileSummary.
        :type chunks_success: float

        :param chunks_fail:
            The value to assign to the chunks_fail property of this UploadFileSummary.
        :type chunks_fail: float

        :param time_started:
            The value to assign to the time_started property of this UploadFileSummary.
        :type time_started: datetime

        :param source_name:
            The value to assign to the source_name property of this UploadFileSummary.
        :type source_name: str

        :param entity_type:
            The value to assign to the entity_type property of this UploadFileSummary.
        :type entity_type: str

        :param entity_name:
            The value to assign to the entity_name property of this UploadFileSummary.
        :type entity_name: str

        :param log_namespace:
            The value to assign to the log_namespace property of this UploadFileSummary.
        :type log_namespace: str

        :param log_group_id:
            The value to assign to the log_group_id property of this UploadFileSummary.
        :type log_group_id: str

        :param log_group_name:
            The value to assign to the log_group_name property of this UploadFileSummary.
        :type log_group_name: str

        :param failure_details:
            The value to assign to the failure_details property of this UploadFileSummary.
        :type failure_details: str

        """
        self.swagger_types = {
            'reference': 'str',
            'name': 'str',
            'status': 'str',
            'total_chunks': 'float',
            'chunks_consumed': 'float',
            'chunks_success': 'float',
            'chunks_fail': 'float',
            'time_started': 'datetime',
            'source_name': 'str',
            'entity_type': 'str',
            'entity_name': 'str',
            'log_namespace': 'str',
            'log_group_id': 'str',
            'log_group_name': 'str',
            'failure_details': 'str'
        }

        self.attribute_map = {
            'reference': 'reference',
            'name': 'name',
            'status': 'status',
            'total_chunks': 'totalChunks',
            'chunks_consumed': 'chunksConsumed',
            'chunks_success': 'chunksSuccess',
            'chunks_fail': 'chunksFail',
            'time_started': 'timeStarted',
            'source_name': 'sourceName',
            'entity_type': 'entityType',
            'entity_name': 'entityName',
            'log_namespace': 'logNamespace',
            'log_group_id': 'logGroupId',
            'log_group_name': 'logGroupName',
            'failure_details': 'failureDetails'
        }

        self._reference = None
        self._name = None
        self._status = None
        self._total_chunks = None
        self._chunks_consumed = None
        self._chunks_success = None
        self._chunks_fail = None
        self._time_started = None
        self._source_name = None
        self._entity_type = None
        self._entity_name = None
        self._log_namespace = None
        self._log_group_id = None
        self._log_group_name = None
        self._failure_details = None

    @property
    def reference(self):
        """
        **[Required]** Gets the reference of this UploadFileSummary.
        Unique internal identifier to refer to upload file


        :return: The reference of this UploadFileSummary.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """
        Sets the reference of this UploadFileSummary.
        Unique internal identifier to refer to upload file


        :param reference: The reference of this UploadFileSummary.
        :type: str
        """
        self._reference = reference

    @property
    def name(self):
        """
        **[Required]** Gets the name of this UploadFileSummary.
        Name of the file


        :return: The name of this UploadFileSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UploadFileSummary.
        Name of the file


        :param name: The name of this UploadFileSummary.
        :type: str
        """
        self._name = name

    @property
    def status(self):
        """
        Gets the status of this UploadFileSummary.
        Processing status of the file.

        Allowed values for this property are: "IN_PROGRESS", "SUCCESSFUL", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this UploadFileSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UploadFileSummary.
        Processing status of the file.


        :param status: The status of this UploadFileSummary.
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "SUCCESSFUL", "FAILED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def total_chunks(self):
        """
        Gets the total_chunks of this UploadFileSummary.
        Number of estimated chunks for this file. A chunk is a portion of the log file used for the processing.


        :return: The total_chunks of this UploadFileSummary.
        :rtype: float
        """
        return self._total_chunks

    @total_chunks.setter
    def total_chunks(self, total_chunks):
        """
        Sets the total_chunks of this UploadFileSummary.
        Number of estimated chunks for this file. A chunk is a portion of the log file used for the processing.


        :param total_chunks: The total_chunks of this UploadFileSummary.
        :type: float
        """
        self._total_chunks = total_chunks

    @property
    def chunks_consumed(self):
        """
        Gets the chunks_consumed of this UploadFileSummary.
        Number of chunks processed


        :return: The chunks_consumed of this UploadFileSummary.
        :rtype: float
        """
        return self._chunks_consumed

    @chunks_consumed.setter
    def chunks_consumed(self, chunks_consumed):
        """
        Sets the chunks_consumed of this UploadFileSummary.
        Number of chunks processed


        :param chunks_consumed: The chunks_consumed of this UploadFileSummary.
        :type: float
        """
        self._chunks_consumed = chunks_consumed

    @property
    def chunks_success(self):
        """
        Gets the chunks_success of this UploadFileSummary.
        Number of chunks processed successfully


        :return: The chunks_success of this UploadFileSummary.
        :rtype: float
        """
        return self._chunks_success

    @chunks_success.setter
    def chunks_success(self, chunks_success):
        """
        Sets the chunks_success of this UploadFileSummary.
        Number of chunks processed successfully


        :param chunks_success: The chunks_success of this UploadFileSummary.
        :type: float
        """
        self._chunks_success = chunks_success

    @property
    def chunks_fail(self):
        """
        Gets the chunks_fail of this UploadFileSummary.
        Number of chunks failed processing


        :return: The chunks_fail of this UploadFileSummary.
        :rtype: float
        """
        return self._chunks_fail

    @chunks_fail.setter
    def chunks_fail(self, chunks_fail):
        """
        Sets the chunks_fail of this UploadFileSummary.
        Number of chunks failed processing


        :param chunks_fail: The chunks_fail of this UploadFileSummary.
        :type: float
        """
        self._chunks_fail = chunks_fail

    @property
    def time_started(self):
        """
        Gets the time_started of this UploadFileSummary.
        The time when this file processing started


        :return: The time_started of this UploadFileSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this UploadFileSummary.
        The time when this file processing started


        :param time_started: The time_started of this UploadFileSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def source_name(self):
        """
        Gets the source_name of this UploadFileSummary.
        Name of the log source used for processing this file


        :return: The source_name of this UploadFileSummary.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this UploadFileSummary.
        Name of the log source used for processing this file


        :param source_name: The source_name of this UploadFileSummary.
        :type: str
        """
        self._source_name = source_name

    @property
    def entity_type(self):
        """
        Gets the entity_type of this UploadFileSummary.
        Name of the entity type


        :return: The entity_type of this UploadFileSummary.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this UploadFileSummary.
        Name of the entity type


        :param entity_type: The entity_type of this UploadFileSummary.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def entity_name(self):
        """
        Gets the entity_name of this UploadFileSummary.
        Name of the entity associated with the file.


        :return: The entity_name of this UploadFileSummary.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this UploadFileSummary.
        Name of the entity associated with the file.


        :param entity_name: The entity_name of this UploadFileSummary.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def log_namespace(self):
        """
        Gets the log_namespace of this UploadFileSummary.
        Log namespace associated with the file.


        :return: The log_namespace of this UploadFileSummary.
        :rtype: str
        """
        return self._log_namespace

    @log_namespace.setter
    def log_namespace(self, log_namespace):
        """
        Sets the log_namespace of this UploadFileSummary.
        Log namespace associated with the file.


        :param log_namespace: The log_namespace of this UploadFileSummary.
        :type: str
        """
        self._log_namespace = log_namespace

    @property
    def log_group_id(self):
        """
        Gets the log_group_id of this UploadFileSummary.
        Log group OCID associated with the file.


        :return: The log_group_id of this UploadFileSummary.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """
        Sets the log_group_id of this UploadFileSummary.
        Log group OCID associated with the file.


        :param log_group_id: The log_group_id of this UploadFileSummary.
        :type: str
        """
        self._log_group_id = log_group_id

    @property
    def log_group_name(self):
        """
        Gets the log_group_name of this UploadFileSummary.
        Log group name associated with the file.


        :return: The log_group_name of this UploadFileSummary.
        :rtype: str
        """
        return self._log_group_name

    @log_group_name.setter
    def log_group_name(self, log_group_name):
        """
        Sets the log_group_name of this UploadFileSummary.
        Log group name associated with the file.


        :param log_group_name: The log_group_name of this UploadFileSummary.
        :type: str
        """
        self._log_group_name = log_group_name

    @property
    def failure_details(self):
        """
        Gets the failure_details of this UploadFileSummary.
        The details about upload processing failure


        :return: The failure_details of this UploadFileSummary.
        :rtype: str
        """
        return self._failure_details

    @failure_details.setter
    def failure_details(self, failure_details):
        """
        Sets the failure_details of this UploadFileSummary.
        The details about upload processing failure


        :param failure_details: The failure_details of this UploadFileSummary.
        :type: str
        """
        self._failure_details = failure_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateClusterNetworkInstancePoolDetails(object):
    """
    The data to create an instance pool in a cluster network.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateClusterNetworkInstancePoolDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateClusterNetworkInstancePoolDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateClusterNetworkInstancePoolDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateClusterNetworkInstancePoolDetails.
        :type freeform_tags: dict(str, str)

        :param instance_configuration_id:
            The value to assign to the instance_configuration_id property of this CreateClusterNetworkInstancePoolDetails.
        :type instance_configuration_id: str

        :param size:
            The value to assign to the size property of this CreateClusterNetworkInstancePoolDetails.
        :type size: int

        """
        self.swagger_types = {
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'instance_configuration_id': 'str',
            'size': 'int'
        }

        self.attribute_map = {
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'instance_configuration_id': 'instanceConfigurationId',
            'size': 'size'
        }

        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._instance_configuration_id = None
        self._size = None

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateClusterNetworkInstancePoolDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateClusterNetworkInstancePoolDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateClusterNetworkInstancePoolDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateClusterNetworkInstancePoolDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateClusterNetworkInstancePoolDetails.
        A user-friendly name. Does not have to be unique. Avoid entering confidential information.


        :return: The display_name of this CreateClusterNetworkInstancePoolDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateClusterNetworkInstancePoolDetails.
        A user-friendly name. Does not have to be unique. Avoid entering confidential information.


        :param display_name: The display_name of this CreateClusterNetworkInstancePoolDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateClusterNetworkInstancePoolDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateClusterNetworkInstancePoolDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateClusterNetworkInstancePoolDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateClusterNetworkInstancePoolDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def instance_configuration_id(self):
        """
        **[Required]** Gets the instance_configuration_id of this CreateClusterNetworkInstancePoolDetails.
        The `OCID`__ of the instance configuration
        associated with the instance pool.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The instance_configuration_id of this CreateClusterNetworkInstancePoolDetails.
        :rtype: str
        """
        return self._instance_configuration_id

    @instance_configuration_id.setter
    def instance_configuration_id(self, instance_configuration_id):
        """
        Sets the instance_configuration_id of this CreateClusterNetworkInstancePoolDetails.
        The `OCID`__ of the instance configuration
        associated with the instance pool.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param instance_configuration_id: The instance_configuration_id of this CreateClusterNetworkInstancePoolDetails.
        :type: str
        """
        self._instance_configuration_id = instance_configuration_id

    @property
    def size(self):
        """
        **[Required]** Gets the size of this CreateClusterNetworkInstancePoolDetails.
        The number of instances that should be in the instance pool.

        For cluster networks with 10 or more instances, the cluster network is created if the required
        number of instances is available and at least 95% of the instances in the pool launch
        successfully. For cluster networks with less than 10 instances, all instances in the pool must
        launch successfully. If the cluster network fails to launch, wait a few minutes, and then try
        creating it again.


        :return: The size of this CreateClusterNetworkInstancePoolDetails.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this CreateClusterNetworkInstancePoolDetails.
        The number of instances that should be in the instance pool.

        For cluster networks with 10 or more instances, the cluster network is created if the required
        number of instances is available and at least 95% of the instances in the pool launch
        successfully. For cluster networks with less than 10 instances, all instances in the pool must
        launch successfully. If the cluster network fails to launch, wait a few minutes, and then try
        creating it again.


        :param size: The size of this CreateClusterNetworkInstancePoolDetails.
        :type: int
        """
        self._size = size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DayOfWeek(object):
    """
    Day of the week.
    """

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "MONDAY"
    NAME_MONDAY = "MONDAY"

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "TUESDAY"
    NAME_TUESDAY = "TUESDAY"

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "WEDNESDAY"
    NAME_WEDNESDAY = "WEDNESDAY"

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "THURSDAY"
    NAME_THURSDAY = "THURSDAY"

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "FRIDAY"
    NAME_FRIDAY = "FRIDAY"

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "SATURDAY"
    NAME_SATURDAY = "SATURDAY"

    #: A constant which can be used with the name property of a DayOfWeek.
    #: This constant has a value of "SUNDAY"
    NAME_SUNDAY = "SUNDAY"

    def __init__(self, **kwargs):
        """
        Initializes a new DayOfWeek object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DayOfWeek.
            Allowed values for this property are: "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        """
        self.swagger_types = {
            'name': 'str'
        }

        self.attribute_map = {
            'name': 'name'
        }

        self._name = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this DayOfWeek.
        Name of the day of the week.

        Allowed values for this property are: "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this DayOfWeek.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DayOfWeek.
        Name of the day of the week.


        :param name: The name of this DayOfWeek.
        :type: str
        """
        allowed_values = ["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsParserMetaPluginParameter(object):
    """
    LogAnalyticsParserMetaPluginParameter
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsParserMetaPluginParameter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this LogAnalyticsParserMetaPluginParameter.
        :type description: str

        :param name:
            The value to assign to the name property of this LogAnalyticsParserMetaPluginParameter.
        :type name: str

        :param is_mandatory:
            The value to assign to the is_mandatory property of this LogAnalyticsParserMetaPluginParameter.
        :type is_mandatory: bool

        :param is_repeatable:
            The value to assign to the is_repeatable property of this LogAnalyticsParserMetaPluginParameter.
        :type is_repeatable: bool

        :param plugin_name:
            The value to assign to the plugin_name property of this LogAnalyticsParserMetaPluginParameter.
        :type plugin_name: str

        :param type:
            The value to assign to the type property of this LogAnalyticsParserMetaPluginParameter.
        :type type: str

        """
        self.swagger_types = {
            'description': 'str',
            'name': 'str',
            'is_mandatory': 'bool',
            'is_repeatable': 'bool',
            'plugin_name': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'name': 'name',
            'is_mandatory': 'isMandatory',
            'is_repeatable': 'isRepeatable',
            'plugin_name': 'pluginName',
            'type': 'type'
        }

        self._description = None
        self._name = None
        self._is_mandatory = None
        self._is_repeatable = None
        self._plugin_name = None
        self._type = None

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsParserMetaPluginParameter.
        parameter description


        :return: The description of this LogAnalyticsParserMetaPluginParameter.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsParserMetaPluginParameter.
        parameter description


        :param description: The description of this LogAnalyticsParserMetaPluginParameter.
        :type: str
        """
        self._description = description

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsParserMetaPluginParameter.
        parameter internal name


        :return: The name of this LogAnalyticsParserMetaPluginParameter.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsParserMetaPluginParameter.
        parameter internal name


        :param name: The name of this LogAnalyticsParserMetaPluginParameter.
        :type: str
        """
        self._name = name

    @property
    def is_mandatory(self):
        """
        Gets the is_mandatory of this LogAnalyticsParserMetaPluginParameter.
        is mandatory flag


        :return: The is_mandatory of this LogAnalyticsParserMetaPluginParameter.
        :rtype: bool
        """
        return self._is_mandatory

    @is_mandatory.setter
    def is_mandatory(self, is_mandatory):
        """
        Sets the is_mandatory of this LogAnalyticsParserMetaPluginParameter.
        is mandatory flag


        :param is_mandatory: The is_mandatory of this LogAnalyticsParserMetaPluginParameter.
        :type: bool
        """
        self._is_mandatory = is_mandatory

    @property
    def is_repeatable(self):
        """
        Gets the is_repeatable of this LogAnalyticsParserMetaPluginParameter.
        is repeatable flag


        :return: The is_repeatable of this LogAnalyticsParserMetaPluginParameter.
        :rtype: bool
        """
        return self._is_repeatable

    @is_repeatable.setter
    def is_repeatable(self, is_repeatable):
        """
        Sets the is_repeatable of this LogAnalyticsParserMetaPluginParameter.
        is repeatable flag


        :param is_repeatable: The is_repeatable of this LogAnalyticsParserMetaPluginParameter.
        :type: bool
        """
        self._is_repeatable = is_repeatable

    @property
    def plugin_name(self):
        """
        Gets the plugin_name of this LogAnalyticsParserMetaPluginParameter.
        plugin internal name


        :return: The plugin_name of this LogAnalyticsParserMetaPluginParameter.
        :rtype: str
        """
        return self._plugin_name

    @plugin_name.setter
    def plugin_name(self, plugin_name):
        """
        Sets the plugin_name of this LogAnalyticsParserMetaPluginParameter.
        plugin internal name


        :param plugin_name: The plugin_name of this LogAnalyticsParserMetaPluginParameter.
        :type: str
        """
        self._plugin_name = plugin_name

    @property
    def type(self):
        """
        Gets the type of this LogAnalyticsParserMetaPluginParameter.
        parameter type


        :return: The type of this LogAnalyticsParserMetaPluginParameter.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this LogAnalyticsParserMetaPluginParameter.
        parameter type


        :param type: The type of this LogAnalyticsParserMetaPluginParameter.
        :type: str
        """
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Connection(object):
    """
    Detailed representation of a connection to a data asset, minus any sensitive properties.
    """

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Connection.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new Connection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Connection.
        :type key: str

        :param description:
            The value to assign to the description property of this Connection.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this Connection.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this Connection.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Connection.
        :type time_updated: datetime

        :param created_by_id:
            The value to assign to the created_by_id property of this Connection.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this Connection.
        :type updated_by_id: str

        :param properties:
            The value to assign to the properties property of this Connection.
        :type properties: dict(str, dict(str, str))

        :param external_key:
            The value to assign to the external_key property of this Connection.
        :type external_key: str

        :param time_status_updated:
            The value to assign to the time_status_updated property of this Connection.
        :type time_status_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Connection.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_default:
            The value to assign to the is_default property of this Connection.
        :type is_default: bool

        :param data_asset_key:
            The value to assign to the data_asset_key property of this Connection.
        :type data_asset_key: str

        :param type_key:
            The value to assign to the type_key property of this Connection.
        :type type_key: str

        :param uri:
            The value to assign to the uri property of this Connection.
        :type uri: str

        """
        self.swagger_types = {
            'key': 'str',
            'description': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'properties': 'dict(str, dict(str, str))',
            'external_key': 'str',
            'time_status_updated': 'datetime',
            'lifecycle_state': 'str',
            'is_default': 'bool',
            'data_asset_key': 'str',
            'type_key': 'str',
            'uri': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'description': 'description',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'properties': 'properties',
            'external_key': 'externalKey',
            'time_status_updated': 'timeStatusUpdated',
            'lifecycle_state': 'lifecycleState',
            'is_default': 'isDefault',
            'data_asset_key': 'dataAssetKey',
            'type_key': 'typeKey',
            'uri': 'uri'
        }

        self._key = None
        self._description = None
        self._display_name = None
        self._time_created = None
        self._time_updated = None
        self._created_by_id = None
        self._updated_by_id = None
        self._properties = None
        self._external_key = None
        self._time_status_updated = None
        self._lifecycle_state = None
        self._is_default = None
        self._data_asset_key = None
        self._type_key = None
        self._uri = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Connection.
        Unique connection key that is immutable.


        :return: The key of this Connection.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Connection.
        Unique connection key that is immutable.


        :param key: The key of this Connection.
        :type: str
        """
        self._key = key

    @property
    def description(self):
        """
        Gets the description of this Connection.
        A description of the connection.


        :return: The description of this Connection.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Connection.
        A description of the connection.


        :param description: The description of this Connection.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this Connection.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this Connection.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Connection.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this Connection.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        Gets the time_created of this Connection.
        The date and time the connection was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Connection.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Connection.
        The date and time the connection was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Connection.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Connection.
        The last time that any change was made to the connection. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Connection.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Connection.
        The last time that any change was made to the connection. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Connection.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this Connection.
        OCID of the user who created the connection.


        :return: The created_by_id of this Connection.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this Connection.
        OCID of the user who created the connection.


        :param created_by_id: The created_by_id of this Connection.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this Connection.
        OCID of the user who modified the connection.


        :return: The updated_by_id of this Connection.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this Connection.
        OCID of the user who modified the connection.


        :param updated_by_id: The updated_by_id of this Connection.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def properties(self):
        """
        Gets the properties of this Connection.
        A map of maps that contains the properties which are specific to the connection type. Each connection type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        connections have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"username\": \"user1\"}}}`


        :return: The properties of this Connection.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this Connection.
        A map of maps that contains the properties which are specific to the connection type. Each connection type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        connections have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"username\": \"user1\"}}}`


        :param properties: The properties of this Connection.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    @property
    def external_key(self):
        """
        Gets the external_key of this Connection.
        Unique external key of this object from the source system.


        :return: The external_key of this Connection.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this Connection.
        Unique external key of this object from the source system.


        :param external_key: The external_key of this Connection.
        :type: str
        """
        self._external_key = external_key

    @property
    def time_status_updated(self):
        """
        Gets the time_status_updated of this Connection.
        Time that the connections status was last updated. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_status_updated of this Connection.
        :rtype: datetime
        """
        return self._time_status_updated

    @time_status_updated.setter
    def time_status_updated(self, time_status_updated):
        """
        Sets the time_status_updated of this Connection.
        Time that the connections status was last updated. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_status_updated: The time_status_updated of this Connection.
        :type: datetime
        """
        self._time_status_updated = time_status_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Connection.
        The current state of the connection.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Connection.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Connection.
        The current state of the connection.


        :param lifecycle_state: The lifecycle_state of this Connection.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def is_default(self):
        """
        Gets the is_default of this Connection.
        Indicates whether this connection is the default connection.


        :return: The is_default of this Connection.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this Connection.
        Indicates whether this connection is the default connection.


        :param is_default: The is_default of this Connection.
        :type: bool
        """
        self._is_default = is_default

    @property
    def data_asset_key(self):
        """
        Gets the data_asset_key of this Connection.
        Unique key of the parent data asset.


        :return: The data_asset_key of this Connection.
        :rtype: str
        """
        return self._data_asset_key

    @data_asset_key.setter
    def data_asset_key(self, data_asset_key):
        """
        Sets the data_asset_key of this Connection.
        Unique key of the parent data asset.


        :param data_asset_key: The data_asset_key of this Connection.
        :type: str
        """
        self._data_asset_key = data_asset_key

    @property
    def type_key(self):
        """
        Gets the type_key of this Connection.
        The key of the object type. Type key's can be found via the '/types' endpoint.


        :return: The type_key of this Connection.
        :rtype: str
        """
        return self._type_key

    @type_key.setter
    def type_key(self, type_key):
        """
        Sets the type_key of this Connection.
        The key of the object type. Type key's can be found via the '/types' endpoint.


        :param type_key: The type_key of this Connection.
        :type: str
        """
        self._type_key = type_key

    @property
    def uri(self):
        """
        Gets the uri of this Connection.
        URI to the connection instance in the API.


        :return: The uri of this Connection.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this Connection.
        URI to the connection instance in the API.


        :param uri: The uri of this Connection.
        :type: str
        """
        self._uri = uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2008-2016 Andrey Petrov and contributors

"""
This module provides means to detect the App Engine environment.
"""

import os


def is_appengine():
    return (is_local_appengine() or
            is_prod_appengine() or
            is_prod_appengine_mvms())


def is_appengine_sandbox():
    return is_appengine() and not is_prod_appengine_mvms()


def is_local_appengine():
    return ('APPENGINE_RUNTIME' in os.environ and
            'Development/' in os.environ['SERVER_SOFTWARE'])


def is_prod_appengine():
    return ('APPENGINE_RUNTIME' in os.environ and
            'Google App Engine/' in os.environ['SERVER_SOFTWARE'] and
            not is_prod_appengine_mvms())


def is_prod_appengine_mvms():
    return os.environ.get('GAE_VM', False) == 'true'
